@@ -11,13 +11,16 @@ Data::iRealPro - Convert iRealBook/iRealPro data
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.17';
 
 =head1 SYNOPSIS
 
-  iRealPro iRealPro_exported.html --output formatted.pdf
-  iRealPro iRealPro_exported.html --output formatted.png
-  iRealPro iRealPro_exported.html --output raw.json
+  irealcvt iRealPro_exported.html --output formatted.pdf
+  irealcvt iRealPro_exported.html --output formatted.png
+  irealcvt iRealPro_exported.html --output raw.json
+  irealcvt iRealPro_exported.html --output editable.txt
+  irealcvt iRealPro_exported.html --output importable.html
+  irealcvt iRealPro_exported.html --list
 
 =head1 DESCRIPTION
 
@@ -28,8 +31,8 @@ and easily. You can use iRealPro for songwriting experiments, as
 accompaniment when learning new songs or for making backing tracks for
 your guitar / saxophone / theremin solos.
 
-iRealPro can import songs in one of two textual format formats. The
-'irealbook' format is easily readable and straightforward. The
+B<iRealPro> can import songs in one of two textual format formats.
+The 'irealbook' format is easily readable and straightforward. The
 official 'irealb' format is proprietary and uses some form of
 scrambling to hide the contents. iRealPro can export songs in the form
 of a HTML document that contains the data in big URLs, and some
@@ -37,7 +40,7 @@ printable formats.
 
 Data::iRealPro provides a set of modules that can be used to read and
 analyse iRealPro songs in URL format and convert them into something
-else, like PDF or PNG. A ready-to-use program iRealPro is provided to
+else, like PDF or PNG. A ready-to-use program irealcvt is provided to
 perform conversions on the command line.
 
 iRealPro web site: L<http://www.irealpro.com>.
@@ -49,8 +52,7 @@ functionality.
 
 Image generation requires L<Imager>. This is optional.
 
-The web backend C<irealpro.cgi> and the text converter C<irpcvt>
-require L<Template::Tiny>.
+The web backend C<irealpro.cgi> requires L<Template::Tiny>.
 
 =head1 AUTHOR
 
@@ -58,9 +60,11 @@ Johan Vromans, C<< <jv at cpan.org> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-music-irealpro at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Music-iRealPro>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<bug-music-irealpro at
+rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Music-iRealPro>. I
+will be notified, and then you'll automatically be notified of
+progress on your bug as I make changes.
 
 =head1 SUPPORT
 
@@ -78,9 +82,7 @@ The iRealPro community, for contributing many, many songs.
 
 Copyright 2013,2016 Johan Vromans, all rights reserved.
 
-For the time being it is not possible to distribute this program as
-free software, since it uses reverse-engineered algorithms to analyse
-the iRealPro song data.
+Clone me at L<GitHub|https://github.com/sciurius/perl-Data-iRealPro>
 
 =cut
 
