@@ -5,8 +5,8 @@
 # Author          : Johan Vromans
 # Created On      : Fri Jan 15 19:15:00 2016
 # Last Modified By: Johan Vromans
-# Last Modified On: Tue Oct  4 13:52:46 2016
-# Update Count    : 1381
+# Last Modified On: Thu Oct  6 21:53:15 2016
+# Update Count    : 1402
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -21,7 +21,7 @@ package Data::iRealPro::Output::Imager;
 
 use parent qw( Data::iRealPro::Output::Base );
 
-our $VERSION = "0.07";
+our $VERSION = "0.08";
 
 use Data::Dumper;
 use Text::CSV_XS;
@@ -162,7 +162,9 @@ sub process {
     my $csv;
     my $csv_fd;
     my $csv_name;
-    if ( $outtype eq "pdf" && !$options->{select} ) {
+    if ( $outtype eq "pdf"
+	 && @{ $u->{playlist}->{songs} } > 1
+	 && !$options->{select} ) {
 	$csv_name = $self->{output};
 	$csv_name =~ s/\.pdf$/.csv/i;
 	open( $csv_fd, ">:encoding(utf8)", $csv_name );
@@ -189,7 +191,7 @@ sub process {
 	$self->{songix} = $songix;
 	my $numpages = $self->make_image( $song, $mx );
 
-	next unless $outtype eq "pdf" && !$options->{select};
+	next unless $csv_fd;
 
 	my $pages = $pageno;
 	if ( $numpages > 1 ) {
@@ -711,10 +713,12 @@ sub make_image {
 	}
 	unless ( $did ) {
 	    my $of = $self->{output};
+	    my $ot = $self->{outtype};
+	    $ot = "jpeg" if $ot eq "jpg";
 	    $of = sprintf( $of, $self->{songix} ) if $of =~ /\%\d*d/;
 	    $of =~ s/\%t/$song->{title}/e;
 	    $self->{im}->write( file => encode_utf8($of),
-				type => $self->{outtype} );
+				type => $ot );
 	    warn( "Wrote: $of\n" ) if $self->{verbose};
 	}
     }
@@ -1022,7 +1026,10 @@ sub initfonts {
 	}
 	if ( $self->{pdf} ) {
 	    unless ( $fontcache{$ff} ) {
-		$fontcache{$ff} ||= $self->{pdf}->ttfont( $ff );
+		unless ( $fontcache{$ff} ) {
+		    my $f = $self->{pdf}->ttfont( $ff );
+		    $fontcache{$ff} = $f;
+		}
 		warn( "$ff: ", $fontcache{$ff}->glyphNum, " glyphs\n" )
 		  if FONTSX;
 	    }
